==> syntool_metadata-1.0.168.tar.gz: syntool_metadata-1.0.168/setup.py <==
# -*- encoding: utf-8 -*-

"""
syntool_metadata: Webservices for Syntool web portals.

Copyright (C) 2014-2021 OceanDataLab

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import os
import sys
import logging
from setuptools import setup
try:
    import subprocess32 as subprocess
except ImportError:
    import subprocess

project_dir = os.path.dirname(__file__)

# use whichcraft to make sure that the "which" command is available
# https://github.com/pydanny/whichcraft/blob/master/whichcraft.py
# bsd-3 clauses licence
sys.path.insert(0, os.path.abspath(project_dir))
from whichcraft import which  # noqa

logger = logging.getLogger()
handler = logging.StreamHandler()
handler.setLevel(logging.DEBUG)
logger.addHandler(handler)
logger.setLevel(logging.WARN)

__package_name__ = 'syntool_metadata'
git_exe = which('git')
git_dir = os.path.join(project_dir, '.git')
readme_path = os.path.join(project_dir, 'README.txt')
version_path = os.path.join(project_dir, 'VERSION.txt')
package_dir = os.path.join(project_dir, __package_name__)
init_file = os.path.join(package_dir, '__init__.py')

# Read metadata from the main __init__.py file
metadata = {}
with open(init_file, 'rt') as f:
    exec(f.read(), metadata)

# Regenerate a version file from git history
if git_exe is not None and os.path.isdir(git_dir):
    import subprocess
    gitrev = (git_exe, 'rev-list', 'HEAD', '--count')
    major, minor = metadata['__version__'].split('.')
    commits = subprocess.check_output(gitrev).decode('utf-8').strip()
    with open(version_path, 'wt') as f:
        f.write('{}.{}.{}'.format(major, minor, commits))

# Refuse to install package if version is not available
if not os.path.isfile(version_path):
    logger.error('Version file "{}" missing.'.format(version_path))
    logger.error('Please use a proper release of the code.')
    sys.exit(1)

with open(version_path, 'rt') as f:
    version = f.read()

with open(readme_path, 'rt') as f:
    long_description = f.read()

setup(
    zip_safe=False,
    name=__package_name__,
    version=version,
    author=metadata['__author__'],
    author_email=metadata['__author_email__'],
    url=metadata['__url__'],
    keywords=metadata['__keywords__'],
    classifiers=metadata['__classifiers__'],
    description=metadata['__description__'],
    packages=(__package_name__,),
    scripts=('bin/syntool-histogram', 'bin/syntool-extract',),
    license='COPYING',
    long_description=long_description,
    install_requires=('sqlalchemy', 'mysqlclient', 'webob', 'routr',),
    extras_require={'full': ('numpy', 'Pillow', 'subprocess32',)},
    package_data={__package_name__: ('share/cfg.ini.sample',
                                     'share/uwsgi.ini',
                                     'share/nginx.conf',)},
)

==> syntool_metadata-1.0.189.tar.gz: syntool_metadata-1.0.189/setup.py <==
# -*- encoding: utf-8 -*-

"""
syntool_metadata: Webservices for Syntool web portals.

Copyright (C) 2014-2024 OceanDataLab

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import os
import sys
import logging
from setuptools import setup
try:
    import subprocess32 as subprocess
except ImportError:
    import subprocess

project_dir = os.path.dirname(__file__)

# use whichcraft to make sure that the "which" command is available
# https://github.com/pydanny/whichcraft/blob/master/whichcraft.py
# bsd-3 clauses licence
sys.path.insert(0, os.path.abspath(project_dir))
from whichcraft import which  # noqa

logger = logging.getLogger()
handler = logging.StreamHandler()
handler.setLevel(logging.DEBUG)
logger.addHandler(handler)
logger.setLevel(logging.WARN)

__package_name__ = 'syntool_metadata'
git_exe = which('git')
git_dir = os.path.join(project_dir, '.git')
readme_path = os.path.join(project_dir, 'README.txt')
version_path = os.path.join(project_dir, 'VERSION.txt')
package_dir = os.path.join(project_dir, __package_name__)
init_file = os.path.join(package_dir, '__init__.py')

# Read metadata from the main __init__.py file
metadata = {}
with open(init_file, 'rt') as f:
    exec(f.read(), metadata)

# Regenerate a version file from git history
if git_exe is not None and os.path.isdir(git_dir):
    import subprocess
    gitrev = (git_exe, 'rev-list', 'HEAD', '--count')
    major, minor = metadata['__version__'].split('.')
    commits = subprocess.check_output(gitrev).decode('utf-8').strip()
    with open(version_path, 'wt') as f:
        f.write('{}.{}.{}'.format(major, minor, commits))

# Refuse to install package if version is not available
if not os.path.isfile(version_path):
    logger.error('Version file "{}" missing.'.format(version_path))
    logger.error('Please use a proper release of the code.')
    sys.exit(1)

with open(version_path, 'rt') as f:
    version = f.read()

with open(readme_path, 'rt') as f:
    long_description = f.read()

setup(
    zip_safe=False,
    name=__package_name__,
    version=version,
    author=metadata['__author__'],
    author_email=metadata['__author_email__'],
    url=metadata['__url__'],
    keywords=metadata['__keywords__'],
    classifiers=metadata['__classifiers__'],
    description=metadata['__description__'],
    packages=(__package_name__,),
    scripts=('bin/syntool-histogram', 'bin/syntool-extract',),
    license='COPYING',
    long_description=long_description,
    install_requires=('sqlalchemy', 'mysqlclient', 'webob', 'routr',),
    extras_require={'full': ('numpy', 'Pillow', 'subprocess32', 'pyproj')},
    package_data={__package_name__: ('share/cfg.ini.sample',
                                     'share/uwsgi.ini',
                                     'share/nginx.conf',)},
)
